[folks/next] TpHandleType has been renamed to TpEntityType
- From: Guillaume Desmottes <gdesmott src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [folks/next] TpHandleType has been renamed to TpEntityType
- Date: Thu, 13 Feb 2014 15:08:08 +0000 (UTC)
commit c0daeaf4ab5fa16bc8b2aeb977e3e7dfe206bc12
Author: Guillaume Desmottes <guillaume desmottes collabora co uk>
Date: Thu Feb 13 12:32:50 2014 +0100
TpHandleType has been renamed to TpEntityType
tests/lib/telepathy/contactlist/backend.c | 2 +-
tests/lib/telepathy/contactlist/bug-19101-conn.c | 2 +-
.../telepathy/contactlist/contact-list-manager.c | 2 +-
tests/lib/telepathy/contactlist/contacts-conn.c | 12 ++++++------
tests/lib/telepathy/contactlist/dbus-tube-chan.c | 6 +++---
tests/lib/telepathy/contactlist/echo-chan.c | 2 +-
tests/lib/telepathy/contactlist/echo-conn.c | 10 +++++-----
tests/lib/telepathy/contactlist/echo-im-manager.c | 6 +++---
.../lib/telepathy/contactlist/file-transfer-chan.c | 2 +-
tests/lib/telepathy/contactlist/room-list-chan.c | 2 +-
tests/lib/telepathy/contactlist/simple-conn.c | 16 ++++++++--------
tests/lib/telepathy/contactlist/stream-tube-chan.c | 8 ++++----
tests/lib/telepathy/contactlist/textchan-group.c | 4 ++--
tests/lib/telepathy/contactlist/util.c | 6 +++---
tests/lib/telepathy/contactlist/util.h | 2 +-
15 files changed, 41 insertions(+), 41 deletions(-)
---
diff --git a/tests/lib/telepathy/contactlist/backend.c b/tests/lib/telepathy/contactlist/backend.c
index 243b4a6..7e1cb0e 100644
--- a/tests/lib/telepathy/contactlist/backend.c
+++ b/tests/lib/telepathy/contactlist/backend.c
@@ -185,7 +185,7 @@ fill_default_roster (AccountData *data)
GQuark conn_features[] = { TP_CONNECTION_FEATURE_CONNECTED, 0 };
repo = tp_base_connection_get_handles (data->base_connection,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
manager = tp_tests_contacts_connection_get_contact_list_manager (conn);
/* Create some contacts and fill some info */
diff --git a/tests/lib/telepathy/contactlist/bug-19101-conn.c
b/tests/lib/telepathy/contactlist/bug-19101-conn.c
index 52a4b68..e707c19 100644
--- a/tests/lib/telepathy/contactlist/bug-19101-conn.c
+++ b/tests/lib/telepathy/contactlist/bug-19101-conn.c
@@ -48,7 +48,7 @@ tp_tests_bug19101_connection_get_contact_by_id (
{
TpBaseConnection *base_conn = TP_BASE_CONNECTION (iface);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (
- base_conn, TP_HANDLE_TYPE_CONTACT);
+ base_conn, TP_ENTITY_TYPE_CONTACT);
TpHandle handle;
GHashTable *table;
diff --git a/tests/lib/telepathy/contactlist/contact-list-manager.c
b/tests/lib/telepathy/contactlist/contact-list-manager.c
index bce8e21..452bcce 100644
--- a/tests/lib/telepathy/contactlist/contact-list-manager.c
+++ b/tests/lib/telepathy/contactlist/contact-list-manager.c
@@ -551,7 +551,7 @@ constructed (GObject *object)
"status-changed", G_CALLBACK (status_changed_cb), self);
self->priv->contact_repo = tp_base_connection_get_handles (self->priv->conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
self->priv->groups = g_hash_table_new_full (g_str_hash, g_str_equal,
g_free, NULL);
}
diff --git a/tests/lib/telepathy/contactlist/contacts-conn.c b/tests/lib/telepathy/contactlist/contacts-conn.c
index 0812a3c..f8148c9 100644
--- a/tests/lib/telepathy/contactlist/contacts-conn.c
+++ b/tests/lib/telepathy/contactlist/contacts-conn.c
@@ -181,7 +181,7 @@ tp_tests_contacts_connection_fill_contact_attributes (TpBaseConnection *base,
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (base);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
if (!tp_strdiff (dbus_interface,
TP_IFACE_CONNECTION_INTERFACE_ALIASING1))
@@ -747,7 +747,7 @@ my_request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (aliasing);
TpBaseConnection *base = TP_BASE_CONNECTION (aliasing);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
GPtrArray *result;
gchar **strings;
GError *error = NULL;
@@ -792,7 +792,7 @@ my_set_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (aliasing);
TpBaseConnection *base = TP_BASE_CONNECTION (aliasing);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
guint n;
GArray *handles;
GPtrArray *aliases;
@@ -856,7 +856,7 @@ my_request_avatars (TpSvcConnectionInterfaceAvatars1 *avatars,
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (avatars);
TpBaseConnection *base = TP_BASE_CONNECTION (avatars);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
GError *error = NULL;
guint i;
@@ -947,7 +947,7 @@ my_refresh_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (obj);
TpBaseConnection *base = TP_BASE_CONNECTION (obj);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
GError *error = NULL;
guint i;
@@ -982,7 +982,7 @@ my_request_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (obj);
TpBaseConnection *base = TP_BASE_CONNECTION (obj);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (base,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
GError *error = NULL;
GPtrArray *ret;
diff --git a/tests/lib/telepathy/contactlist/echo-chan.c b/tests/lib/telepathy/contactlist/echo-chan.c
index 9234a6a..6442378 100644
--- a/tests/lib/telepathy/contactlist/echo-chan.c
+++ b/tests/lib/telepathy/contactlist/echo-chan.c
@@ -132,7 +132,7 @@ tp_tests_echo_channel_class_init (TpTestsEchoChannelClass *klass)
object_class->finalize = finalize;
base_class->channel_type = TP_IFACE_CHANNEL_TYPE_TEXT;
- base_class->target_handle_type = TP_HANDLE_TYPE_CONTACT;
+ base_class->target_entity_type = TP_ENTITY_TYPE_CONTACT;
base_class->get_interfaces = tp_tests_echo_channel_get_interfaces;
base_class->close = channel_close;
diff --git a/tests/lib/telepathy/contactlist/echo-conn.c b/tests/lib/telepathy/contactlist/echo-conn.c
index e985ec6..4863879 100644
--- a/tests/lib/telepathy/contactlist/echo-conn.c
+++ b/tests/lib/telepathy/contactlist/echo-conn.c
@@ -73,16 +73,16 @@ tp_tests_echo_normalize_contact (TpHandleRepoIface *repo,
static void
create_handle_repos (TpBaseConnection *conn,
- TpHandleRepoIface *repos[TP_NUM_HANDLE_TYPES])
+ TpHandleRepoIface *repos[TP_NUM_ENTITY_TYPES])
{
((TpBaseConnectionClass *)
tp_tests_echo_connection_parent_class)->create_handle_repos (conn, repos);
/* Replace the contacts handle repo with our own, for special normalization */
- g_assert (repos[TP_HANDLE_TYPE_CONTACT] != NULL);
- g_object_unref (repos[TP_HANDLE_TYPE_CONTACT]);
- repos[TP_HANDLE_TYPE_CONTACT] = tp_dynamic_handle_repo_new
- (TP_HANDLE_TYPE_CONTACT, tp_tests_echo_normalize_contact, NULL);
+ g_assert (repos[TP_ENTITY_TYPE_CONTACT] != NULL);
+ g_object_unref (repos[TP_ENTITY_TYPE_CONTACT]);
+ repos[TP_ENTITY_TYPE_CONTACT] = tp_dynamic_handle_repo_new
+ (TP_ENTITY_TYPE_CONTACT, tp_tests_echo_normalize_contact, NULL);
}
static GPtrArray *
diff --git a/tests/lib/telepathy/contactlist/echo-im-manager.c
b/tests/lib/telepathy/contactlist/echo-im-manager.c
index 8c38186..ea091ce 100644
--- a/tests/lib/telepathy/contactlist/echo-im-manager.c
+++ b/tests/lib/telepathy/contactlist/echo-im-manager.c
@@ -260,7 +260,7 @@ new_channel (TpTestsEchoImManager *self,
static const gchar * const fixed_properties[] = {
TP_PROP_CHANNEL_CHANNEL_TYPE,
- TP_PROP_CHANNEL_TARGET_HANDLE_TYPE,
+ TP_PROP_CHANNEL_TARGET_ENTITY_TYPE,
NULL
};
@@ -278,7 +278,7 @@ tp_tests_echo_im_manager_foreach_channel_class (TpChannelManager *manager,
GHashTable *table = tp_asv_new (
TP_PROP_CHANNEL_CHANNEL_TYPE,
G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_TEXT,
- TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT, TP_HANDLE_TYPE_CONTACT,
+ TP_PROP_CHANNEL_TARGET_ENTITY_TYPE, G_TYPE_UINT, TP_ENTITY_TYPE_CONTACT,
NULL);
@@ -305,7 +305,7 @@ tp_tests_echo_im_manager_request (TpTestsEchoImManager *self,
}
if (tp_asv_get_uint32 (request_properties,
- TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL) != TP_HANDLE_TYPE_CONTACT)
+ TP_PROP_CHANNEL_TARGET_ENTITY_TYPE, NULL) != TP_ENTITY_TYPE_CONTACT)
{
return FALSE;
}
diff --git a/tests/lib/telepathy/contactlist/file-transfer-chan.c
b/tests/lib/telepathy/contactlist/file-transfer-chan.c
index 3bc8d89..813826e 100644
--- a/tests/lib/telepathy/contactlist/file-transfer-chan.c
+++ b/tests/lib/telepathy/contactlist/file-transfer-chan.c
@@ -614,7 +614,7 @@ tp_tests_file_transfer_channel_class_init (
object_class->dispose = dispose;
base_class->channel_type = TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER1;
- base_class->target_handle_type = TP_HANDLE_TYPE_CONTACT;
+ base_class->target_entity_type = TP_ENTITY_TYPE_CONTACT;
base_class->close = channel_close;
base_class->fill_immutable_properties = fill_immutable_properties;
diff --git a/tests/lib/telepathy/contactlist/room-list-chan.c
b/tests/lib/telepathy/contactlist/room-list-chan.c
index a3a7a8c..a71b29c 100644
--- a/tests/lib/telepathy/contactlist/room-list-chan.c
+++ b/tests/lib/telepathy/contactlist/room-list-chan.c
@@ -134,7 +134,7 @@ tp_tests_room_list_chan_class_init (
oclass->finalize = tp_tests_room_list_chan_finalize;
base_class->channel_type = TP_IFACE_CHANNEL_TYPE_ROOM_LIST1;
- base_class->target_handle_type = TP_HANDLE_TYPE_NONE;
+ base_class->target_entity_type = TP_ENTITY_TYPE_NONE;
base_class->fill_immutable_properties = fill_immutable_properties;
base_class->close = room_list_chan_close;
diff --git a/tests/lib/telepathy/contactlist/simple-conn.c b/tests/lib/telepathy/contactlist/simple-conn.c
index fa7bfda..0c716bd 100644
--- a/tests/lib/telepathy/contactlist/simple-conn.c
+++ b/tests/lib/telepathy/contactlist/simple-conn.c
@@ -174,12 +174,12 @@ tp_tests_simple_normalize_contact (TpHandleRepoIface *repo,
static void
create_handle_repos (TpBaseConnection *conn,
- TpHandleRepoIface *repos[TP_NUM_HANDLE_TYPES])
+ TpHandleRepoIface *repos[TP_NUM_ENTITY_TYPES])
{
- repos[TP_HANDLE_TYPE_CONTACT] = tp_dynamic_handle_repo_new
- (TP_HANDLE_TYPE_CONTACT, tp_tests_simple_normalize_contact, NULL);
- repos[TP_HANDLE_TYPE_ROOM] = tp_dynamic_handle_repo_new
- (TP_HANDLE_TYPE_ROOM, NULL, NULL);
+ repos[TP_ENTITY_TYPE_CONTACT] = tp_dynamic_handle_repo_new
+ (TP_ENTITY_TYPE_CONTACT, tp_tests_simple_normalize_contact, NULL);
+ repos[TP_ENTITY_TYPE_ROOM] = tp_dynamic_handle_repo_new
+ (TP_ENTITY_TYPE_ROOM, NULL, NULL);
}
static GPtrArray *
@@ -202,7 +202,7 @@ pretend_connected (gpointer data)
TpTestsSimpleConnection *self = TP_TESTS_SIMPLE_CONNECTION (data);
TpBaseConnection *conn = (TpBaseConnection *) self;
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
TpHandle self_handle;
self_handle = tp_handle_ensure (contact_repo, self->priv->account,
@@ -326,7 +326,7 @@ tp_tests_simple_connection_set_identifier (TpTestsSimpleConnection *self,
{
TpBaseConnection *conn = (TpBaseConnection *) self;
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
TpHandle handle = tp_handle_ensure (contact_repo, identifier, NULL, NULL);
/* if this fails then the identifier was bad - caller error */
@@ -359,7 +359,7 @@ tp_tests_simple_connection_ensure_text_chan (TpTestsSimpleConnection *self,
/* Get contact handle */
contact_repo = tp_base_connection_get_handles (base_conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
g_assert (contact_repo != NULL);
handle = tp_handle_ensure (contact_repo, target_id, NULL, NULL);
diff --git a/tests/lib/telepathy/contactlist/textchan-group.c
b/tests/lib/telepathy/contactlist/textchan-group.c
index b305876..fedb002 100644
--- a/tests/lib/telepathy/contactlist/textchan-group.c
+++ b/tests/lib/telepathy/contactlist/textchan-group.c
@@ -146,7 +146,7 @@ constructed (GObject *object)
self->conn = tp_base_channel_get_connection (base);
contact_repo = tp_base_connection_get_handles (self->conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
tp_base_channel_register (base);
@@ -223,7 +223,7 @@ tp_tests_text_channel_group_class_init (TpTestsTextChannelGroupClass *klass)
object_class->finalize = finalize;
base_class->channel_type = TP_IFACE_CHANNEL_TYPE_TEXT;
- base_class->target_handle_type = TP_HANDLE_TYPE_NONE;
+ base_class->target_entity_type = TP_ENTITY_TYPE_NONE;
base_class->get_interfaces = text_channel_group_get_interfaces;
base_class->close = channel_close;
diff --git a/tests/lib/telepathy/contactlist/util.c b/tests/lib/telepathy/contactlist/util.c
index 67af4e0..88045b0 100644
--- a/tests/lib/telepathy/contactlist/util.c
+++ b/tests/lib/telepathy/contactlist/util.c
@@ -636,7 +636,7 @@ TpChannel *
tp_tests_channel_new (TpConnection *conn,
const gchar *object_path,
const gchar *optional_channel_type,
- TpHandleType optional_handle_type,
+ TpEntityType optional_handle_type,
TpHandle optional_handle,
GError **error)
{
@@ -650,10 +650,10 @@ tp_tests_channel_new (TpConnection *conn,
tp_asv_set_string (asv,
TP_PROP_CHANNEL_CHANNEL_TYPE, optional_channel_type);
}
- if (optional_handle_type != TP_HANDLE_TYPE_NONE)
+ if (optional_handle_type != TP_ENTITY_TYPE_NONE)
{
tp_asv_set_uint32 (asv,
- TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, optional_handle_type);
+ TP_PROP_CHANNEL_TARGET_ENTITY_TYPE, optional_handle_type);
}
if (optional_handle != 0)
{
diff --git a/tests/lib/telepathy/contactlist/util.h b/tests/lib/telepathy/contactlist/util.h
index 183e00f..74e5a3e 100644
--- a/tests/lib/telepathy/contactlist/util.h
+++ b/tests/lib/telepathy/contactlist/util.h
@@ -97,7 +97,7 @@ TpAccount *tp_tests_account_new (TpDBusDaemon *dbus,
TpChannel *tp_tests_channel_new (TpConnection *conn,
const gchar *object_path,
const gchar *optional_channel_type,
- TpHandleType optional_handle_type,
+ TpEntityType optional_handle_type,
TpHandle optional_handle,
GError **error);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/tests/lib/telepathy/contactlist/dbus-tube-chan.c
b/tests/lib/telepathy/contactlist/dbus-tube-chan.c
index 3a67b0f..d2de191 100644
--- a/tests/lib/telepathy/contactlist/dbus-tube-chan.c
+++ b/tests/lib/telepathy/contactlist/dbus-tube-chan.c
@@ -241,7 +241,7 @@ tp_tests_dbus_tube_channel_class_init (TpTestsDBusTubeChannelClass *klass)
base_class->close = channel_close;
base_class->fill_immutable_properties = fill_immutable_properties;
/* base_class->target_handle_type is defined in subclasses */
param_spec = g_param_spec_string ("service-name", "Service Name",
"the service name associated with this tube object.",
@@ -430,7 +430,7 @@ tp_tests_contact_dbus_tube_channel_class_init (
{
TpBaseChannelClass *base_class = TP_BASE_CHANNEL_CLASS (klass);
- base_class->target_handle_type = TP_HANDLE_TYPE_CONTACT;
+ base_class->target_entity_type = TP_ENTITY_TYPE_CONTACT;
}
/* Room DBus Tube */
@@ -451,5 +451,5 @@ tp_tests_room_dbus_tube_channel_class_init (
{
TpBaseChannelClass *base_class = TP_BASE_CHANNEL_CLASS (klass);
- base_class->target_handle_type = TP_HANDLE_TYPE_ROOM;
+ base_class->target_entity_type = TP_ENTITY_TYPE_ROOM;
}
@@ -241,7 +241,7 @@ tp_tests_dbus_tube_channel_class_init (TpTestsDBusTubeChannelClass *klass)
base_class->close = channel_close;
base_class->fill_immutable_properties = fill_immutable_properties;
- /* base_class->target_handle_type is defined in subclasses */
+ /* base_class->target_entity_type is defined in subclasses */
param_spec = g_param_spec_string ("service-name", "Service Name",
"the service name associated with this tube object.",
diff --git a/tests/lib/telepathy/contactlist/stream-tube-chan.c
b/tests/lib/telepathy/contactlist/stream-tube-chan.c
index a85f3b5..8a41064 100644
--- a/tests/lib/telepathy/contactlist/stream-tube-chan.c
+++ b/tests/lib/telepathy/contactlist/stream-tube-chan.c
@@ -277,7 +277,7 @@ tp_tests_stream_tube_channel_class_init (TpTestsStreamTubeChannelClass *klass)
base_class->close = channel_close;
base_class->fill_immutable_properties = fill_immutable_properties;
/* base_class->target_handle_type is defined in subclasses */
param_spec = g_param_spec_string ("service", "service name",
"the service associated with this tube object.",
@@ -529,7 +529,7 @@ tp_tests_stream_tube_channel_peer_connected (TpTestsStreamTubeChannel *self,
TpBaseChannel *base = (TpBaseChannel *) self;
TpBaseConnection *conn = tp_base_channel_get_connection (base);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (conn,
- TP_HANDLE_TYPE_CONTACT);
+ TP_ENTITY_TYPE_CONTACT);
if (self->priv->state == TP_TUBE_CHANNEL_STATE_REMOTE_PENDING)
change_state (self, TP_TUBE_CHANNEL_STATE_OPEN);
@@ -625,7 +625,7 @@ tp_tests_contact_stream_tube_channel_class_init (
{
TpBaseChannelClass *base_class = TP_BASE_CHANNEL_CLASS (klass);
- base_class->target_handle_type = TP_HANDLE_TYPE_CONTACT;
+ base_class->target_entity_type = TP_ENTITY_TYPE_CONTACT;
}
/* Room Stream Tube */
@@ -646,5 +646,5 @@ tp_tests_room_stream_tube_channel_class_init (
{
TpBaseChannelClass *base_class = TP_BASE_CHANNEL_CLASS (klass);
- base_class->target_handle_type = TP_HANDLE_TYPE_ROOM;
+ base_class->target_entity_type = TP_ENTITY_TYPE_ROOM;
}
@@ -277,7 +277,7 @@ tp_tests_stream_tube_channel_class_init (TpTestsStreamTubeChannelClass *klass)
base_class->close = channel_close;
base_class->fill_immutable_properties = fill_immutable_properties;
- /* base_class->target_handle_type is defined in subclasses */
+ /* base_class->target_entity_type is defined in subclasses */
param_spec = g_param_spec_string ("service", "service name",
"the service associated with this tube object.",